@@ -19,7 +19,7 @@ from requests.exceptions import HTTPError
 
 from toolchest_client.api.auth import get_headers
 from toolchest_client.api.exceptions import ToolchestDownloadError
-from toolchest_client.api.urls import PIPELINE_SEGMENT_INSTANCES_URL
+from toolchest_client.api.urls import get_pipeline_segment_instances_url
 from toolchest_client.files import get_file_type, get_params_from_s3_uri, unpack_files
 
 
@@ -69,7 +69,7 @@ def download(output_path, s3_uri=None, pipeline_segment_instance_id=None, run_id
     # Note: Assumes that output_path is a directory if it does not exist.
     # This may lead to undesired leaf dir creation if output_path is not intended to be a dir,
     # but support for non-dir output_path will likely be deprecated.
-    output_path = os.path.abspath(output_path)
+    output_path = os.path.abspath(os.path.expanduser(output_path))
     if not os.path.exists(output_path) and output_type is None:
         if "." in os.path.basename(output_path):
             logging.warning(f"Creating {os.path.basename(output_path)} as a directory along path {output_path}")
@@ -107,7 +107,7 @@ def get_download_details(pipeline_segment_instance_id):
     """Gets S3 URI and access keys for downloading output of query task(s)."""
 
     response = requests.get(
-        "/".join([PIPELINE_SEGMENT_INSTANCES_URL, pipeline_segment_instance_id, "downloads"]),
+        "/".join([get_pipeline_segment_instances_url(), pipeline_segment_instance_id, "downloads"]),
         headers=get_headers(),
     )
     try:
